@@ -33,7 +33,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL.php,v 1.1 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL.php,v 1.2 2006/12/11 12:00:31 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -49,7 +49,6 @@ define('SYL_VERSION', '0.5.1');
 define('SYL_DIR', dirname(__FILE__));
 define('SYL_CONFIG_DIR',  SYL_DIR . '/config');
 define('SYL_INCLUDE_DIR', SYL_DIR . '/include');
-define('SYL_WEBAPP_DIR',  SYL_DIR . '/webapp');
 
 /**
  * ƥ⥳ȥ̾
@@ -80,7 +79,18 @@ define('SYL_CONFIG_SYSTEM_ERROR_LOG', true);
 /**
  * PHPƥ२顼¸ե
  */
-define('SYL_CONFIG_SYSTEM_ERROR_LOG_FILE', SYL_DIR . '/users/syslogs/phperror_' . date('Ymd') . '.log');
+define('SYL_CONFIG_SYSTEM_ERROR_LOG_FILE', SYL_DIR . '/resource/syslogs/phperror_' . date('Ymd') . '.log');
+
+/**
+ * ǥХå٥
+ */
+define('SYL_LOG_NONE',    0);
+define('SYL_LOG_ERROR',   1); // = E_ERROR
+define('SYL_LOG_WARN',    2); // = E_WARNING
+define('SYL_LOG_NOTICE',  8); // = E_NOTICE
+define('SYL_LOG_INFO',   16);
+define('SYL_LOG_DEBUG',  32);
+
 
 /*
 DIRECTORY_SEPARATOR
