@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigDefines extends SyL_Config
@@ -73,23 +73,10 @@ class SyL_ConfigDefines extends SyL_Config
     function getElement($current_path, $attribute, $text)
     {
         if ($current_path == '/define/param') {
-            if (!defined($attribute['name'])) {
-                $text = preg_replace_callback('/(.*)\{([^\}]+)\}(.*)/', array(&$this, 'replaceConstant'), $text);
-                define($attribute['name'], $text);
-            }
+            $this->config[$attribute['name']] = $text;
         }
     }
 
-    /**
-     * 萔uR[obN\bh
-     *
-     * @access public
-     * @param array }b`z
-     */
-    function replaceConstant($matches)
-    {
-        return defined($matches[2]) ? ($matches[1] . constant($matches[2]) . $matches[3]) : $matches[0];
-    }
 }
 
 ?>
