@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -58,7 +58,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Error.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -68,10 +68,11 @@ class SyL_ErrorWeb extends SyL_Error
      * 
      * @access public
      * @param string 顼å
+     * @param int 顼٥
      */
-    function end($error_string='')
+    function trigger($error_string='', $error_type=E_USER_ERROR)
     {
-        trigger_error($error_string, E_USER_ERROR);
+        trigger_error($error_string, $error_type);
     }
 
     /**
@@ -89,7 +90,7 @@ class SyL_ErrorWeb extends SyL_Error
         // ߤΥ顼٥뤫饨顼̤ɽ뤫Ƚ
         if ($error_no & error_reporting()) {
             // Хåե󥰥ꥢ
-          //  while (@ob_end_clean());
+            while (@ob_end_clean());
 
             // ʣ顼åб
             if (count($this->error_message) > 0) {
@@ -156,8 +157,8 @@ class SyL_ErrorWeb extends SyL_Error
         // 顼å
         $error_string = "[" . $error_type . "] " . $error_message;
         $include_file = '';
-        if (is_file(SYL_APP_DIR . '/' . SYL_ERROR_FORWARD_FILE)) {
-            $include_file = SYL_APP_DIR . '/' . SYL_ERROR_FORWARD_FILE;
+        if (is_file(SYL_WEBAPP_DIR . '/' . SYL_ERROR_FORWARD_FILE)) {
+            $include_file = SYL_WEBAPP_DIR . '/' . SYL_ERROR_FORWARD_FILE;
         } else if (is_file(SYL_DIR . '/' . SYL_ERROR_FORWARD_FILE)) {
             $include_file = SYL_DIR . '/' . SYL_ERROR_FORWARD_FILE;
         } else if (is_file(SYL_ERROR_FORWARD_FILE)) {
