@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestCookie.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestCookie.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -56,7 +56,7 @@ define('SYL_COOKIE_SECURE', 0);
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestCookie.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestCookie.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestCookie extends SyL_Request
@@ -70,6 +70,10 @@ class SyL_RequestCookie extends SyL_Request
     {
         // ѥ᡼
         $this->parameters =& $_COOKIE;
+        // ޥåݥȤͭȽ
+        if (get_magic_quotes_gpc()) {
+            $this->applyParametersRecursive($this->parameters, 'stripslashes');
+        }
     }
 
     /**
