@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestParameter.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestParameter.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Request.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestParameter.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestParameter.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestParameter extends SyL_Request
@@ -56,18 +56,19 @@ class SyL_RequestParameter extends SyL_Request
      */
     function SyL_RequestParameter()
     {
-        $parameters = array();
-
         // ѥ᡼
         if ($_SERVER['REQUEST_METHOD'] == 'POST') {
-            $parameters =& $_POST;
-            $parameters = array_merge($parameters, $_GET);
+            $this->parameters =& $_POST;
+            $this->parameters = array_merge($this->parameters, $_GET);
         } else {
-            $parameters =& $_GET;
-            $parameters = array_merge($parameters, $_POST);
+            $this->parameters =& $_GET;
+            $this->parameters = array_merge($this->parameters, $_POST);
         }
 
-        $this->parameters =& $parameters;
+        // ޥåݥȤͭȽ
+        if (get_magic_quotes_gpc()) {
+            $this->applyParametersRecursive($this->parameters, 'stripslashes');
+        }
     }
 }
 
