@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -151,15 +151,15 @@ echo "</pre>";
                 if (is_file(SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'])) {
                     // SyLǥ쥯ȥ꤫Υѥ
                     include_once SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'];
-                } else if (defined('SYL_APP_DIR') && is_file(SYL_APP_DIR . DIRECTORY_SEPARATOR . $keys['file'])) {
+                } else if (is_file(SYL_WEBAPP_DIR . DIRECTORY_SEPARATOR . $keys['file'])) {
                     // ץꥱǥ쥯ȥ꤫Υѥ
-                    include_once SYL_APP_DIR . DIRECTORY_SEPARATOR . $keys['file'];
+                    include_once SYL_WEBAPP_DIR . DIRECTORY_SEPARATOR . $keys['file'];
                 } else if (is_file($keys['file'])) {
                     // եѥ
                     include_once $keys['file'];
                 } else {
                     // ݡͥȥե뤬̵
-                    $this->log('info', "Component or Action or Filter include failed: file not found ({$keys['file']} or " . SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'] . " or " . SYL_APP_DIR . DIRECTORY_SEPARATOR . $keys['file'] . ")");
+                    $this->log('info', "Component include failed: file not found ({$keys['file']} or " . SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'] . " or " . SYL_APP_DIR . DIRECTORY_SEPARATOR . $keys['file'] . ")");
                     // ٥Ⱥ
                     $this->deleteEventConfig($name, $name, $event, $keys, $tmp_config);
                     continue;
@@ -250,7 +250,7 @@ echo "</pre>";
                 case 'constructor':
                     $ref = $keys['reference'] ? '&' : '';
                     if (is_file(SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'])) {
-                        include_once(SYL_DIR . DIRECTORY_SEPARATOR . $keys['file']);
+                        include_once SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'];
                         if ($funcs[1] != '') {
                             eval('$component =' . $ref . ' ' . $classname  . '::' . $funcs[1] . '(' . $eval_args . ');');
                         } else {
