@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -83,7 +83,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Container.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -162,6 +162,12 @@ class SyL_Controller
             trigger_error("[SyL error] Controller parameter action_key not exists", E_USER_ERROR);
         }
 
+        // å
+        define('SYL_CACHE_DIR', (isset($config['cache_dir']) && $config['cache_dir']) ? $config['cache_dir'] : false);
+        // ǥХå٥
+        define('SYL_DEBUG', (isset($config['debug']) && is_numeric($config['debug'])) ? $config['debug'] : SYL_LOG_NOTICE);
+        // WEBץꥱǥ쥯ȥ
+        define('SYL_WEBAPP_DIR', (isset($config['webapp_dir']) && $config['webapp_dir']) ? $config['webapp_dir'] : SYL_DIR . '/webapp');
         // ץꥱǥ쥯ȥ
         define('SYL_APP_DIR', SYL_WEBAPP_DIR . '/' . $this->app_name);
 
@@ -171,9 +177,9 @@ class SyL_Controller
         }
 
         // ǥ쥯ȥ
-        $this->action_dir = (isset($config['action_dir']) && $config['action_dir']) ? $config['action_dir'] : SYL_APP_DIR . '/actions';
+        $this->action_dir = SYL_APP_DIR . '/actions';
         // ƥץ졼ȥǥ쥯ȥ
-        $this->template_dir = (isset($config['template_dir']) && $config['template_dir']) ? $config['template_dir'] : SYL_APP_DIR . '/templates';
+        $this->template_dir = SYL_APP_DIR . '/templates';
 
         // ɤ߹
         SyL_DefinesReader::readConfig($this);
