@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DefinesReader.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DefinesReader.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,6 +36,10 @@
  * ե륯饹
  */
 require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
+/**
+ * å奯饹
+ */
+require_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
 
 /**
  * եɤ߹९饹
@@ -44,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DefinesReader.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DefinesReader.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DefinesReader
@@ -52,6 +56,7 @@ class SyL_DefinesReader
     /**
      * 󥹥ȥ饯
      *
+     * @static
      * @access public
      * @param string XMLե̾
      * @param object ȥ饪֥
@@ -59,27 +64,79 @@ class SyL_DefinesReader
     function readConfig(&$controller)
     {
         // ץꥱͤɤ߹
-        $config_file = SYL_WEBAPP_DIR . DIRECTORY_SEPARATOR . $controller->app_name . DIRECTORY_SEPARATOR . SYL_CONFIG_DEFINE_FILE;
-        SyL_DefinesReader::_readConfig($config_file, $controller);
+        $config_file1 = SYL_WEBAPP_DIR . DIRECTORY_SEPARATOR . $controller->app_name . DIRECTORY_SEPARATOR . SYL_CONFIG_DEFINE_FILE;
         // Хͤɤ߹
-        $config_file = SYL_CONFIG_DIR . DIRECTORY_SEPARATOR . SYL_CONFIG_DEFINE_FILE;
-        SyL_DefinesReader::_readConfig($config_file, $controller);
+        $config_file2 = SYL_CONFIG_DIR . DIRECTORY_SEPARATOR . SYL_CONFIG_DEFINE_FILE;
+
+        $config = array();
+        if (SYL_CACHE_DIR) {
+            // åѤ
+            $cache =& SyL_Cache::getObject($config_file1, 'fileupdate');
+            $cache->setCacheDir(SYL_CACHE_DIR);
+            $config = $cache->read(array($config_file1, $config_file2));
+            if (!$config) {
+                $config = array();
+                $config += SyL_DefinesReader::readConfigFile($config_file1, $controller);
+                $config += SyL_DefinesReader::readConfigFile($config_file2, $controller);
+                $cache->write($config);
+            }
+        } else {
+            // åѤʤ
+            $config += SyL_DefinesReader::readConfigFile($config_file1, $controller);
+            $config += SyL_DefinesReader::readConfigFile($config_file2, $controller);
+        }
+
+        // ɤ߹
+        SyL_DefinesReader::readDefine($config);
     }
 
     /**
      * ɤ߹
      *
-     * @access private
+     * @static
+     * @access public
      * @param string ե̾
      * @param object ȥ饪֥
      */
-    function _readConfig($config_file, &$controller)
+    function readConfigFile($config_file, &$controller)
     {
         if (is_file($config_file)) {
             $config =& SyL_Config::getObject('defines', $config_file, $controller);
             $config->parseXML();
+            return $config->getConfig();
+        } else {
+            return false;
         }
     }
+
+    /**
+     * ɤ߹
+     *
+     * @static
+     * @access public
+     * @param string ե̾
+     * @param object ȥ饪֥
+     */
+    function readDefine($config)
+    {
+        foreach ($config as $key => $value) {
+            $value = preg_replace_callback('/(.*)\{([^\}]+)\}(.*)/', array('SyL_DefinesReader', 'replaceConstant'), $value);
+            define($key, $value);
+        }
+    }
+
+    /**
+     * ֤Хå᥽å
+     *
+     * @static
+     * @access public
+     * @param array ޥå
+     @ return mixed ޥå
+     */
+    function replaceConstant($matches)
+    {
+        return defined($matches[2]) ? ($matches[1] . constant($matches[2]) . $matches[3]) : $matches[0];
+    }
 }
 
 ?>
