@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.3 2006/12/09 08:35:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loggers.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.3 2006/12/09 08:35:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -112,14 +112,10 @@ class SyL_Error
      * 
      * @access public
      * @param string 顼å
+     * @param int 顼٥
      */
-    function trigger($error_string='')
+    function trigger($error_string='', $error_type=E_USER_ERROR)
     {
-        $e =& SyL_Error::getInstance();
-        if (is_subclass_of($e, 'SyL_Error') && in_array('end', get_class_methods(get_class($e)))) {
-            // ֥饹Ǥ
-            $e->end($error_string);
-        }
     }
 
     /**
@@ -169,7 +165,7 @@ class SyL_Error
      * @param  int    顼No
      * @return string 顼̾
      */
-    function getErrorType( $errorNo )
+    function getErrorType($errorNo)
     {
         switch ($errorNo) {
         case E_ERROR           : return 'Error';
@@ -183,8 +179,12 @@ class SyL_Error
         case E_USER_ERROR      : return 'User Error';
         case E_USER_WARNING    : return 'User Warning';
         case E_USER_NOTICE     : return 'User Notice';
-        default                : return 'Unknonwn';
+        default:
+          if (defined('E_STRICT') && ($errorNo == E_STRICT)) return 'Strict';
+          if (defined('E_RECOVERABLE_ERROR') && ($errorNo == E_RECOVERABLE_ERROR)) return 'Recoverable Error';
         }
+
+        return 'Unknonwn';
     }
 
     /**
@@ -226,7 +226,7 @@ class SyL_Error
      */
     function logging($error_no, $error_message)
     {
-        if (class_exists('SyL_Loggers')) {
+        if (class_exists('SyL_Loggers') && ($error_no <= SYL_DEBUG)) {
             $log_string  = '[' . $this->getErrorType($error_no) . '] ' . $error_message . $this->eof;
             foreach ($this->getTrace() as $value) {
                 $log_string .= "[file] "     . $value['file'] . " ";
