@@ -27,42 +27,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loggers.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loggers.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * ٥
- *
- * E_ERROR   =>  1
- * E_WARNING =>  2
- * E_NOTICE  =>  8
- * 
- *  SYL_LOG_NONE  => (̵)
- *  SYL_LOG_ERROR => SYL_LOG_ERROR 
- *  SYL_LOG_WARN  => SYL_LOG_ERROR 
- *                       SYL_LOG_WARN  
- *  SYL_LOG_NOTICE => SYL_LOG_ERROR 
- *                       SYL_LOG_WARN   
- *                       SYL_LOG_NOTICE 
- *  SYL_LOG_INFO  => SYL_LOG_ERROR 
- *                       SYL_LOG_WARN  
- *                       SYL_LOG_NOTICE 
- *                       SYL_LOG_INFO  
- *  SYL_LOG_DEBUG  => SYL_LOG_ERROR 
- *                        SYL_LOG_WARN  
- *                        SYL_LOG_NOTICE 
- *                        SYL_LOG_INFO  
- *                        SYL_LOG_DEBUG 
- */
-define('SYL_LOG_NONE',   0);
-define('SYL_LOG_ERROR',  E_ERROR);
-define('SYL_LOG_WARN',   E_WARNING);
-define('SYL_LOG_NOTICE', E_NOTICE);
-define('SYL_LOG_INFO',   16);
-define('SYL_LOG_DEBUG',  32);
-
 /**
  * 饹
  */
@@ -75,7 +44,7 @@ require_once 'SyL_Logger.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loggers.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loggers.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Loggers
@@ -120,7 +89,7 @@ class SyL_Loggers
      * 
      * @access public
      * @param object ֥
-     * @param string ƥ꥿
+     * @param int ٥
      */
     function setLogger(&$logger, $mode=SYL_LOG_NOTICE)
     {
