@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -78,7 +78,7 @@ class SyL_View
             $class_name = $lm->getCustomizedViewClass();
             $class_file = $lm->getCustomizedViewFile();
             if (!is_file($class_file)) {
-                $class_file1 = SYL_APP_DIR . DIRECTORY_SEPARATOR . $class_file;
+                $class_file1 = SYL_WEBAPP_DIR . DIRECTORY_SEPARATOR . $class_file;
                 if (!is_file($class_file1)) {
                     trigger_error("[SyL error] Customised View file not found ({$class_file} or {$class_file1})", E_USER_ERROR);
                 }
