@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.3 2006/12/09 08:35:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.4 2006/12/11 11:59:19 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -45,7 +45,7 @@ define( 'DB_DEBUG', false );
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.3 2006/12/09 08:35:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.4 2006/12/11 11:59:19 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -179,7 +179,7 @@ class SyL_DB
 
             $class_name = 'SyL_DB_' . $dbtype;
             // ¥󥹥󥹺
-            include_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'DB' . DIRECTORY_SEPARATOR . $class_name . '.php';
+            include_once dirname(__FILE__) . "/DB/{$class_name}.php";
             $singleton[$dsn] = new $class_name($dbtype, $client_encode, $server_encode);
             $singleton[$dsn]->openConnection($dbname, $user, $passwd, $host, $port, $persistent);
         }
